@@ -3,6 +3,7 @@ package phase
 import (
 	"strings"
 
+	"github.com/alessio/shellescape"
 	"github.com/k0sproject/k0sctl/pkg/apis/k0sctl.k0sproject.io/v1beta1/cluster"
 	"github.com/k0sproject/rig/os"
 	log "github.com/sirupsen/logrus"
@@ -69,5 +70,11 @@ func (p *PrepareHosts) prepareHost(h *cluster.Host) error {
 		}
 	}
 
+	if h.DataDir == "" {
+		log.Debugf("%s: data-dir is not set, using default", h)
+		h.DataDir = h.Configurer.DataDirDefaultPath()
+	}
+	h.DataDir = shellescape.Quote(h.DataDir)
+
 	return nil
 }
